@@ -5,7 +5,6 @@ use strict;
 
 use Carp qw/ confess /;
 use File::Temp qw/ tempfile /;
-use POSIX qw(:sys_wait_h);
 
 use base 'Test::Builder::Module';
 
@@ -41,6 +40,11 @@ our @EXPORT = qw(
                   stderr_is_file
 
                   );
+                  
+my $posix_ok       = eval { require POSIX; };
+my $wait_macros_ok = defined &POSIX::WIFEXITED;
+eval { POSIX::WIFEXITED() };
+$wait_macros_ok = 0 if $@;                   
 
 =head1 NAME
 
@@ -48,11 +52,11 @@ Test::Command - Test routines for external commands
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -397,9 +401,31 @@ sub _run_cmd
 
    ## run the command
    system(@{ $cmd });
-   my $system_return = defined ${^CHILD_ERROR_NATIVE} ? ${^CHILD_ERROR_NATIVE}      : $?;
-   my $exit_status   = WIFEXITED($system_return)      ? WEXITSTATUS($system_return) : undef;
-   my $term_signal   = WIFSIGNALED($system_return)    ? WTERMSIG($system_return)    : undef;
+
+   my $system_return = defined ${^CHILD_ERROR_NATIVE} ? ${^CHILD_ERROR_NATIVE} : $?;
+   
+   my $exit_status;
+   my $term_signal;
+
+   if ( $wait_macros_ok )
+      {
+      $exit_status = POSIX::WIFEXITED($system_return)   ? POSIX::WEXITSTATUS($system_return) : undef;
+      $term_signal = POSIX::WIFSIGNALED($system_return) ? POSIX::WTERMSIG($system_return)    : undef;
+      }
+   else
+      {
+      my $wait_status = $system_return & 127;
+      if ($wait_status)
+         {
+         $exit_status = undef;
+         $term_signal = $wait_status;
+         }
+      else
+         {
+         $exit_status = $system_return >> 8;
+         $term_signal = undef;
+         }
+      }
 
    ## close and restore STDOUT and STDERR to original handles
    close STDOUT or confess "failed to close STDOUT: $!";
